@@ -1,4 +1,6 @@
 from .bp.create_outgoing_event import CreateOutgoingEvent
+from .bp.create_image_block import CreateImageBlock
+from .bp.create_image_button import CreateImageButton
 from .bp import *
 from .svc import *
 from .dmo import *
@@ -56,6 +58,47 @@ def normalize_event(d_event: dict,
     return NormalizeIncomingEvent(bot_ids).process(d_event)
 
 
+def create_image_block(image_url: str,
+                       d_event_incoming: dict) -> dict:
+    """ Create an Image-only Blocks Response
+
+    Args:
+        image_url (str): a public URL for a slack image
+        d_event_incoming (dict): the incoming slack event
+            -   This is required to obtain the channel, thread timestamp (thread_ts) and input text (text)
+            -   It was thought easier to pass the original (non-normalized) Slack event as a parameter value
+                than to request these individual values
+
+    Returns:
+        dict: the outgoing slack event
+    """
+    return CreateImageBlock().process(
+        image_url=image_url,
+        d_event_incoming=d_event_incoming)
+
+
+def create_image_button(d_event_incoming: dict,
+                        output_text: str,
+                        image_url: str,
+                        button_text: str = "View Page") -> dict:
+    """ Create and Format Outgoing Slack Events
+
+    Args:
+        d_event_incoming (dict): the incoming slack event
+        output_text (str): the incoming slack event
+        image_url (str): a public URL for a slack image
+        button_text (str): the button text
+
+    Returns:
+        dict: the outgoing slack event
+    """
+    return CreateImageButton().process(
+        image_url=image_url,
+        output_text=output_text,
+        button_text=button_text,
+        d_event_incoming=d_event_incoming)
+
+
 def create_outgoing_event(output_text: str,
                           d_event_incoming: dict) -> dict:
     """ Create an Outgoing Slack Event
